[PATCH] fix a couple of issues with current bk


Subject: [PATCH] fix a couple of issues with current bk
From: Benjamin Herrenschmidt (benh@kernel.crashing.org)
Date: Sat Mar 31 2001 - 10:02:55 MST


That first one is a hack to fixes compile

===== util/dv/dumpvars.c 1.10 vs edited =====
--- 1.10/util/dv/dumpvars.c Wed Mar 28 23:14:30 2001
+++ edited/util/dv/dumpvars.c Sat Mar 31 16:39:32 2001
@@ -107,7 +107,7 @@
   LABEL("Private variables to 'base.S'"),
         {BVAR(in_splitmode), " in_splitmode "},
         {BVAR(prepare_splitmode), " prepare_splitmode "},
- {BVAR(split_nip), " splitmode_nip (when singlestepping) "},
+ //{BVAR(split_nip), " splitmode_nip (when singlestepping) "},
         {BVAR(split_nip_segment), " split_nip_segment "},
 
         {BVAR(emulator_stack), " saved stack (used when going to mac_mode) "},

This one increase the buffer size for the network interface name in
sheep_net, it's needed for the new airport driver (airport0 is too
large for it ;)

===== netdriver/sheep.c 1.11 vs edited =====
--- 1.11/netdriver/sheep.c Sat Nov 11 20:09:14 2000
+++ edited/netdriver/sheep.c Sat Mar 31 17:17:28 2001
@@ -392,9 +392,9 @@
 
         switch (code) {
         // Attach to Ethernet card
// arg: pointer to name of Ethernet device (char[8])
         case SIOCSIFLINK: {
- char name[8];
+ char name[20];
                 int err;
 
                 // Already attached?
@@ -402,9 +402,9 @@
                         return -EBUSY;
 
                 // Get Ethernet card name
- if (copy_from_user(name, (void *)arg, 8))
+ if (copy_from_user(name, (void *)arg, 20))
                         return -EFAULT;
- name[7] = 0;
+ name[19] = 0;
 
                 // Find card
 #ifdef LINUX_24
@@ -392,9 +392,9 @@
         switch (code) {
         // Attach to Ethernet card
- // arg: pointer to name of Ethernet device (char[8])
+ // arg: pointer to name of Ethernet device (char[20])
         case SIOCSIFLINK: {

Note that I'm running the current MOL bk with 2.4.3 final, and I didn't
(yet) experience the weird problem I reported you earlier while still
loading the machine significantly on both sides.

Ben.



This archive was generated by hypermail 2a24 : Sat Mar 31 2001 - 09:14:02 MST